@@ -9,7 +9,7 @@ import scipy
 from quantdsl import DslParser, Number, Add, Max, On, Date, String, FunctionDef, \
     Name, Compare, IfExp, FunctionCall, Sub, QuantDslSyntaxError, Mult, Div, UnarySub, Pow, Mod, FloorDiv, \
     ExpressionStack, If, TimeDelta, Module, parse, compile, eval, utc, LeastSquares, DslNamespace, DslExpression, \
-    PriceSimulator
+    BlackScholesPriceProcess
 
 
 def suite():
@@ -567,7 +567,7 @@ Swing(Date('2011-01-01'), Date('2011-01-03'), 10, 500)
 #            'image': MockImage(MockPriceProcess()),
             'interestRate': 0,
             'presentTime': datetime.datetime(2011, 1, 1, tzinfo=utc),
-            'brownianMotions': {
+            'allMarketPrices': {
                 '#1': dict([(datetime.datetime(2011, 1, 1, tzinfo=utc) + datetime.timedelta(1) * i, numpy.array([10])) for i in range(0, 30)])
 
             },
@@ -697,7 +697,7 @@ class DslTestCase(unittest.TestCase):
                 '#2-LAST-PRICE': 10,
                 '#2-ACTUAL-HISTORICAL-VOLATILITY': 50,
             },
-            'allRvs': PriceSimulator().getAllRvs(dslExpr, observationTime, pathCount=500000),
+            'allRvs': BlackScholesPriceProcess().getAllRvs(dslExpr, observationTime, pathCount=500000),
         })
         assert isinstance(dslExpr, DslExpression)
         value = dslExpr.evaluate(**evaluationKwds)
